// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'dart:ui';

import 'package:copy_with_extension/copy_with_extension.dart';
import 'package:flutter/widgets.dart';
import 'package:wyatt_ui_components/src/core/utils/multi_color.dart';
import 'package:wyatt_ui_components/src/domain/entities/buttons/button_style.dart';

part 'simple_icon_button_style.g.dart';

@CopyWith()
class SimpleIconButtonStyle extends ButtonStyle<SimpleIconButtonStyle> {
  const SimpleIconButtonStyle({
    this.dimension,
    super.radius,
    super.padding,
    super.foregroundColors,
    super.backgroundColors,
    super.borderColors,
    super.stroke,
    super.shadow,
  });

  /// Used for interpolation.
  static SimpleIconButtonStyle? lerp(
    SimpleIconButtonStyle? a,
    SimpleIconButtonStyle? b,
    double t,
  ) {
    if (a == null || b == null) {
      return null;
    }
    // b.copyWith to return b attributes even if they are not lerped
    return b.copyWith(
      dimension: lerpDouble(a.dimension, b.dimension, t),
      foregroundColors: MultiColor.lerp(
        a.foregroundColors,
        b.foregroundColors,
        t,
      ),
      backgroundColors: MultiColor.lerp(
        a.backgroundColors,
        b.backgroundColors,
        t,
      ),
      borderColors: MultiColor.lerp(
        a.borderColors,
        b.borderColors,
        t,
      ),
      radius: BorderRadiusGeometry.lerp(a.radius, b.radius, t),
      padding: EdgeInsetsGeometry.lerp(a.padding, b.padding, t),
      stroke: lerpDouble(a.stroke, b.stroke, t),
      shadow: BoxShadow.lerp(a.shadow, b.shadow, t),
    );
  }

  /// Dimension of this button (as a square)
  ///
  /// Default to `context.buttonTheme.height`
  final double? dimension;
}
